#ident	"@(#)ops.head	25.1	12/2/91 Copyright (c) 1991 by Arix Corp."
/*			*/
/*	@(#)ops.head	7.1		*/
/*			*/
/*	@(#) ops.head:	4.1 84/06/27	*/

/* MC68000 Optimizer */

/* Definitions of opcode related things. */


#define	MAXOPS	2		/* Two operands per instruction, max. */
typedef	unsigned short OPCODE;	/* Object holding opcode number */

typedef unsigned short FLAGS;	/* holds operation flag bits */

/* This structure contains the invariant information for each instruction.
** For transfers of control (jumps, branches, subroutine calls, etc.), the
** highest numbered operand is assumed to contain the control target.
*/

typedef struct op
{
    char * op_name;		/* pointer to instruction print-name */
    OPCODE op_code;		/* operation code number for instruction */
    unsigned char op_nsrc;	/* number of source operands.  Source operands
				** are those for which the processor does a
				** read cycle.  For example, add.w has two
				** source operands, while mov.w has just one.
				** Source operands are assumed to be consec-
				** utive, starting with the first operand.
				*/
    unsigned char op_dnum;	/* Destination operand number.  If the op has
				** no destination, value is NODEST.  A desti-
				** nation operand is one whose value is changed.
				** In add.l, the second operand is both a source
				** AND a destination operand, whereas the
				** second operand of mov.l is just a dest.
				*/
    unsigned char op_ssize[MAXOPS];
				/* size of each source operand, addressed as
				** 0 - MAXOPS-1, in bytes.
				*/
    unsigned char op_dsize;	/* size of destination operand, in bytes */
    OPCODE op_opposite;		/* op code of "opposite" instruction, in
				** some sense.  For example, for conditional
				** jumps, this is the "reversed" branch.
				*/
    FLAGS op_flags;		/* various flag bits for inst. -- see below */
} OP;


#define	NODEST	0xFF		/* value meaning no destination */
#define	NOOPP	'\0'		/* value meaning no opposite instruction */

/* Define flags for op_flags field.  These are bit flags. */

#define	OF_LAB		0x001	/* op is normal label */
#define	OF_UBRA		0x002	/* op is unconditional branch */
#define	OF_HLAB		0x004	/* op is hard label */
#define	OF_HBRA		0x008	/* op is hard branch */
#define	OF_CBRA		0x010	/* op is conditional branch */
#define	OF_NCBRA	0x020	/* op is conditional branch with null
				** destination (e.g., trapv)
				*/
#define	OF_RCBRA	0x040	/* op is reversible conditional branch */
#define	OF_CC		0x080	/* op affects condition codes */
#define	OF_CCA		0x100	/* op affects condition codes, except if
				** destination is address register
				*/
#define	OF_COMUOP	0x200	/* op is a communative operator */
#define	OF_LD		0x400	/* op has funny live/dead characteristics */
#define	OF_VTRACE	0x800	/* op has funny value trace behavior */
#define	OF_FLOAT	0x1000	/* op supports floating-point registers */
#define	OF_PSEUDO	0x2000	/* op is a pseudo-op */
#define OF_RT4		0x4000	/* op has a base size of 4 bytes */
#define OF_NOLEAF	0x8000	/* op calls another procedure */
/* Define op code numbers.  These numbers form a 1 to 1
** correspondence with the op code names in optab.c .  The order must
** be identical: the ASCII collating sequence for the op names.  The
** numbers must be sequential.
*/

#define OP_MIN		10	/* Min. opcode no. */

#define ABCD_B      	10	/* abcd.b */
#define ADD_B      	11	/* add.b */
#define ADD_L      	12	/* add.l */
#define ADD_W      	13	/* add.w */
#define ADDX_B      	14	/* addx.b */
#define ADDX_L      	15	/* addx.l */
#define ADDX_W      	16	/* addx.w */
#define ALIGN      	17	/* align */
#define AND_B      	18	/* and.b */
#define AND_L      	19	/* and.l */
#define AND_W      	20	/* and.w */
#define ASL_B      	21	/* asl.b */
#define ASL_L      	22	/* asl.l */
#define ASL_W      	23	/* asl.w */
#define ASR_B      	24	/* asr.b */
#define ASR_L      	25	/* asr.l */
#define ASR_W      	26	/* asr.w */
#define BCC      	27	/* bcc */
#define BCC_B      	28	/* bcc.b */
#define BCHG      	29	/* bchg */
#define BCLR      	30	/* bclr */
#define BCS      	31	/* bcs */
#define BCS_B      	32	/* bcs.b */
#define BEQ      	33	/* beq */
#define BEQ_B      	34	/* beq.b */
#define BFCHG      	35	/* bfchg */
#define BFCLR      	36	/* bfclr */
#define BFEXTS      	37	/* bfexts */
#define BFEXTU      	38	/* bfextu */
#define BFFFO      	39	/* bfffo */
#define BFINS      	40	/* bfins */
#define BFSET      	41	/* bfset */
#define BFTST      	42	/* bftst */
#define BGE      	43	/* bge */
#define BGE_B      	44	/* bge.b */
#define BGT      	45	/* bgt */
#define BGT_B      	46	/* bgt.b */
#define BHI      	47	/* bhi */
#define BHI_B      	48	/* bhi.b */
#define BHS      	49	/* bhs */
#define BHS_B      	50	/* bhs.b */
#define BLE      	51	/* ble */
#define BLE_B      	52	/* ble.b */
#define BLO      	53	/* blo */
#define BLO_B      	54	/* blo.b */
#define BLS      	55	/* bls */
#define BLS_B      	56	/* bls.b */
#define BLT      	57	/* blt */
#define BLT_B      	58	/* blt.b */
#define BMI      	59	/* bmi */
#define BMI_B      	60	/* bmi.b */
#define BNE      	61	/* bne */
#define BNE_B      	62	/* bne.b */
#define BPL      	63	/* bpl */
#define BPL_B      	64	/* bpl.b */
#define BR      	65	/* br */
#define BR_B      	66	/* br.b */
#define BRA      	67	/* bra */
#define BRA_B      	68	/* bra.b */
#define BSET      	69	/* bset */
#define BSR      	70	/* bsr */
#define BSR_B      	71	/* bsr.b */
#define BTST      	72	/* btst */
#define BVC      	73	/* bvc */
#define BVC_B      	74	/* bvc.b */
#define BVS      	75	/* bvs */
#define BVS_B      	76	/* bvs.b */
#define BYTE      	77	/* byte */
#define CHK_W      	78	/* chk.w */
#define CLR_B      	79	/* clr.b */
#define CLR_L      	80	/* clr.l */
#define CLR_W      	81	/* clr.w */
#define CMP_B      	82	/* cmp.b */
#define CMP_L      	83	/* cmp.l */
#define CMP_W      	84	/* cmp.w */
#define COMM      	85	/* comm */
#define DATA      	86	/* data */
#define DBCC      	87	/* dbcc */
#define DBCS      	88	/* dbcs */
#define DBEQ      	89	/* dbeq */
#define DBF      	90	/* dbf */
#define DBGE      	91	/* dbge */
#define DBGT      	92	/* dbgt */
#define DBHI      	93	/* dbhi */
#define DBHS      	94	/* dbhs */
#define DBLE      	95	/* dble */
#define DBLO      	96	/* dblo */
#define DBLS      	97	/* dbls */
#define DBLT      	98	/* dblt */
#define DBMI      	99	/* dbmi */
#define DBNE      	100	/* dbne */
#define DBPL      	101	/* dbpl */
#define DBR      	102	/* dbr */
#define DBRA      	103	/* dbra */
#define DBT      	104	/* dbt */
#define DBVC      	105	/* dbvc */
#define DBVS      	106	/* dbvs */
#define DEF      	107	/* def */
#define DIVS_L      	108	/* divs.l */
#define DIVS_W      	109	/* divs.w */
#define DIVU_L      	110	/* divu.l */
#define DIVU_W      	111	/* divu.w */
#define EOR_B      	112	/* eor.b */
#define EOR_L      	113	/* eor.l */
#define EOR_W      	114	/* eor.w */
#define EVEN      	115	/* even */
#define EXG      	116	/* exg */
#define EXT_L      	117	/* ext.l */
#define EXT_W      	118	/* ext.w */
#define EXTB_L      	119	/* extb.l */
#define FABS_B      	120	/* fabs.b */
#define FABS_D      	121	/* fabs.d */
#define FABS_L      	122	/* fabs.l */
#define FABS_S      	123	/* fabs.s */
#define FABS_W      	124	/* fabs.w */
#define FABS_X      	125	/* fabs.x */
#define FACOS_B      	126	/* facos.b */
#define FACOS_D      	127	/* facos.d */
#define FACOS_L      	128	/* facos.l */
#define FACOS_S      	129	/* facos.s */
#define FACOS_W      	130	/* facos.w */
#define FACOS_X      	131	/* facos.x */
#define FADD_B      	132	/* fadd.b */
#define FADD_D      	133	/* fadd.d */
#define FADD_L      	134	/* fadd.l */
#define FADD_S      	135	/* fadd.s */
#define FADD_W      	136	/* fadd.w */
#define FADD_X      	137	/* fadd.x */
#define FASIN_B      	138	/* fasin.b */
#define FASIN_D      	139	/* fasin.d */
#define FASIN_L      	140	/* fasin.l */
#define FASIN_S      	141	/* fasin.s */
#define FASIN_W      	142	/* fasin.w */
#define FASIN_X      	143	/* fasin.x */
#define FATAN_B      	144	/* fatan.b */
#define FATAN_D      	145	/* fatan.d */
#define FATAN_L      	146	/* fatan.l */
#define FATAN_S      	147	/* fatan.s */
#define FATAN_W      	148	/* fatan.w */
#define FATAN_X      	149	/* fatan.x */
#define FATANH_B      	150	/* fatanh.b */
#define FATANH_D      	151	/* fatanh.d */
#define FATANH_L      	152	/* fatanh.l */
#define FATANH_S      	153	/* fatanh.s */
#define FATANH_W      	154	/* fatanh.w */
#define FATANH_X      	155	/* fatanh.x */
#define FBEQ      	156	/* fbeq */
#define FBF       	157	/* fbf */
#define FBGE      	158	/* fbge */
#define FBGL      	159	/* fbgl */
#define FBGLE      	160	/* fbgle */
#define FBGT      	161	/* fbgt */
#define FBLE      	162	/* fble */
#define FBLT      	163	/* fblt */
#define FBNEQ      	164	/* fbneq */
#define FBNGE      	165	/* fbnge */
#define FBNGL      	166	/* fbngl */
#define FBNGLE      	167	/* fbngle */
#define FBNGT      	168	/* fbngt */
#define FBNLE      	169	/* fbnle */
#define FBNLT      	170	/* fbnlt */
#define FBOGE      	171	/* fboge */
#define FBOGL      	172	/* fbogl */
#define FBOGT      	173	/* fbogt */
#define FBOLE      	174	/* fbole */
#define FBOLT      	175	/* fbolt */
#define FBOR      	176	/* fbor */
#define FBSEQ      	177	/* fbseq */
#define FBSF      	178	/* fbsf */
#define FBSNEQ      	179	/* fbsneq */
#define FBST      	180	/* fbst */
#define FBT      	181	/* fbt */
#define FBUEQ      	182	/* fbueq */
#define FBUGE      	183	/* fbuge */
#define FBUGT       	184	/* fbugt */
#define FBULE      	185	/* fbule */
#define FBULT      	186	/* fbult */
#define FBUN      	187	/* fbun */
#define FCMP_B      	188	/* fcmp.b */
#define FCMP_D      	189	/* fcmp.d */
#define FCMP_L      	190	/* fcmp.l */
#define FCMP_S      	191	/* fcmp.s */
#define FCMP_W      	192	/* fcmp.w */
#define FCMP_X      	193	/* fcmp.x */
#define FCOS_B      	194	/* fcos.b */
#define FCOS_D      	195	/* fcos.d */
#define FCOS_L      	196	/* fcos.l */
#define FCOS_S      	197	/* fcos.s */
#define FCOS_W      	198	/* fcos.w */
#define FCOS_X      	199	/* fcos.x */
#define FCOSH_B      	200	/* fcosh.b */
#define FCOSH_D      	201	/* fcosh.d */
#define FCOSH_L      	202	/* fcosh.l */
#define FCOSH_S      	203	/* fcosh.s */
#define FCOSH_W      	204	/* fcosh.w */
#define FCOSH_X      	205	/* fcosh.x */
#define FDIV_B      	206	/* fdiv.b */
#define FDIV_D      	207	/* fdiv.d */
#define FDIV_L      	208	/* fdiv.l */
#define FDIV_S      	209	/* fdiv.s */
#define FDIV_W      	210	/* fdiv.w */
#define FDIV_X      	211	/* fdiv.x */
#define FETOX_B      	212	/* fetox.b */
#define FETOX_D      	213	/* fetox.d */
#define FETOX_L      	214	/* fetox.l */
#define FETOX_S      	215	/* fetox.s */
#define FETOX_W      	216	/* fetox.w */
#define FETOX_X      	217	/* fetox.x */
#define FETOXM1_B      	218	/* fetoxm1.b */
#define FETOXM1_D      	219	/* fetoxm1.d */
#define FETOXM1_L      	220	/* fetoxm1.l */
#define FETOXM1_S      	221	/* fetoxm1.s */
#define FETOXM1_W      	222	/* fetoxm1.w */
#define FETOXM1_X      	223	/* fetoxm1.x */
#define FGETEXP_B      	224	/* fgetexp.b */
#define FGETEXP_D      	225	/* fgetexp.d */
#define FGETEXP_L      	226	/* fgetexp.l */
#define FGETEXP_S      	227	/* fgetexp.s */
#define FGETEXP_W      	228	/* fgetexp.w */
#define FGETEXP_X      	229	/* fgetexp.x */
#define FGETMAN_B      	230	/* fgetman.b */
#define FGETMAN_D      	231	/* fgetman.d */
#define FGETMAN_L      	232	/* fgetman.l */
#define FGETMAN_S      	233	/* fgetman.s */
#define FGETMAN_W      	234	/* fgetman.w */
#define FGETMAN_X      	235	/* fgetman.x */
#define FILE_      	236	/* file */
#define FINT_B      	237	/* fint.b */
#define FINT_D      	238	/* fint.d */
#define FINT_L      	239	/* fint.l */
#define FINT_S      	240	/* fint.s */
#define FINT_W      	241	/* fint.w */
#define FINT_X      	242	/* fint.x */
#define FINTRZ_B      	243	/* fintrz.b */
#define FINTRZ_D      	244	/* fintrz.d */
#define FINTRZ_L      	245	/* fintrz.l */
#define FINTRZ_S      	246	/* fintrz.s */
#define FINTRZ_W      	247	/* fintrz.w */
#define FINTRZ_X      	248	/* fintrz.x */
#define FLOG10_B      	249	/* flog10.b */
#define FLOG10_D      	250	/* flog10.d */
#define FLOG10_L      	251	/* flog10.l */
#define FLOG10_S      	252	/* flog10.s */
#define FLOG10_W      	253	/* flog10.w */
#define FLOG10_X      	254	/* flog10.x */
#define FLOG2_B      	255	/* flog2.b */
#define FLOG2_D      	256	/* flog2.d */
#define FLOG2_L      	257	/* flog2.l */
#define FLOG2_S      	258	/* flog2.s */
#define FLOG2_W      	259	/* flog2.w */
#define FLOG2_X      	260	/* flog2.x */
#define FLOGN_B      	261	/* flogn.b */
#define FLOGN_D      	262	/* flogn.d */
#define FLOGN_L      	263	/* flogn.l */
#define FLOGN_S      	264	/* flogn.s */
#define FLOGN_W      	265	/* flogn.w */
#define FLOGN_X      	266	/* flogn.x */
#define FLOGNP1_B      	267	/* flognp1.b */
#define FLOGNP1_D      	268	/* flognp1.d */
#define FLOGNP1_L      	269	/* flognp1.l */
#define FLOGNP1_S      	270	/* flognp1.s */
#define FLOGNP1_W      	271	/* flognp1.w */
#define FLOGNP1_X      	272	/* flognp1.x */
#define FMOD_B      	273	/* fmod.b */
#define FMOD_D      	274	/* fmod.d */
#define FMOD_L      	275	/* fmod.l */
#define FMOD_S      	276	/* fmod.s */
#define FMOD_W      	277	/* fmod.w */
#define FMOD_X      	278	/* fmod.x */
#define FMOV_B      	279	/* fmov.b */
#define FMOV_D      	280	/* fmov.d */
#define FMOV_L      	281	/* fmov.l */
#define FMOV_S      	282	/* fmov.s */
#define FMOV_W      	283	/* fmov.w */
#define FMOV_X      	284	/* fmov.x */
#define FMOVCR      	285	/* fmovcr */
#define FMOVM      	286	/* fmovm */
#define FMUL_B      	287	/* fmul.b */
#define FMUL_D      	288	/* fmul.d */
#define FMUL_L      	289	/* fmul.l */
#define FMUL_S      	290	/* fmul.s */
#define FMUL_W      	291	/* fmul.w */
#define FMUL_X      	292	/* fmul.x */
#define FNEG_B      	293	/* fneg.b */
#define FNEG_D      	294	/* fneg.d */
#define FNEG_L      	295	/* fneg.l */
#define FNEG_S      	296	/* fneg.s */
#define FNEG_W      	297	/* fneg.w */
#define FNEG_X      	298	/* fneg.x */
#define FNOP      	299	/* fnop */
#define FREM_B      	300	/* frem.b */
#define FREM_D      	301	/* frem.d */
#define FREM_L      	302	/* frem.l */
#define FREM_S      	303	/* frem.s */
#define FREM_W      	304	/* frem.w */
#define FREM_X      	305	/* frem.x */
#define FRESTORE      	306	/* frestore */
#define FSAVE      	307	/* fsave */
#define FSCALE_B      	308	/* fscale.b */
#define FSCALE_D      	309	/* fscale.d */
#define FSCALE_L      	310	/* fscale.l */
#define FSCALE_S      	311	/* fscale.s */
#define FSCALE_W      	312	/* fscale.w */
#define FSCALE_X      	313	/* fscale.x */
#define FSEQ      	314	/* fseq.b */
#define FSF      	315	/* fsf.b */
#define FSGE      	316	/* fsge.b */
#define FSGLDIV_B      	317	/* fsgldiv.b */
#define FSGLDIV_D      	318	/* fsgldiv.d */
#define FSGLDIV_L      	319	/* fsgldiv.l */
#define FSGLDIV_S      	320	/* fsgldiv.s */
#define FSGLDIV_W      	321	/* fsgldiv.w */
#define FSGLDIV_X      	322	/* fsgldiv.x */
#define FSGLMUL_B      	323	/* fsglmul.b */
#define FSGLMUL_D      	324	/* fsglmul.d */
#define FSGLMUL_L      	325	/* fsglmul.l */
#define FSGLMUL_S      	326	/* fsglmul.s */
#define FSGLMUL_W      	327	/* fsglmul.w */
#define FSGLMUL_X      	328	/* fsglmul.x */
#define FSGT      	329	/* fsgt.b */
#define FSIN_B      	330	/* fsin.b */
#define FSIN_D      	331	/* fsin.d */
#define FSIN_L      	332	/* fsin.l */
#define FSIN_S      	333	/* fsin.s */
#define FSIN_W      	334	/* fsin.w */
#define FSIN_X      	335	/* fsin.x */
#define FSINCOS_B      	336	/* fsincos.b */
#define FSINCOS_D      	337	/* fsincos.d */
#define FSINCOS_L      	338	/* fsincos.l */
#define FSINCOS_S      	339	/* fsincos.s */
#define FSINCOS_W      	340	/* fsincos.w */
#define FSINCOS_X      	341	/* fsincos.x */
#define FSINH_B      	342	/* fsinh.b */
#define FSINH_D      	343	/* fsinh.d */
#define FSINH_L      	344	/* fsinh.l */
#define FSINH_S      	345	/* fsinh.s */
#define FSINH_W      	346	/* fsinh.w */
#define FSINH_X      	347	/* fsinh.x */
#define FSLE      	348	/* fsle.b */
#define FSLT      	349	/* fslt.b */
#define FSNEQ      	350	/* fsneq.b */
#define FSNGE      	351	/* fsnge.b */
#define FSQRT_B      	352	/* fsqrt.b */
#define FSQRT_D      	353	/* fsqrt.d */
#define FSQRT_L      	354	/* fsqrt.l */
#define FSQRT_S      	355	/* fsqrt.s */
#define FSQRT_W      	356	/* fsqrt.w */
#define FSQRT_X      	357	/* fsqrt.x */
#define FST      	358	/* fst.b */
#define FSUB_B      	359	/* fsub.b */
#define FSUB_D      	360	/* fsub.d */
#define FSUB_L      	361	/* fsub.l */
#define FSUB_S      	362	/* fsub.s */
#define FSUB_W      	363	/* fsub.w */
#define FSUB_X      	364	/* fsub.x */
#define FTAN_B      	365	/* ftan.b */
#define FTAN_D      	366	/* ftan.d */
#define FTAN_L      	367	/* ftan.l */
#define FTAN_S      	368	/* ftan.s */
#define FTAN_W      	369	/* ftan.w */
#define FTAN_X      	370	/* ftan.x */
#define FTANH_B      	371	/* ftanh.b */
#define FTANH_D      	372	/* ftanh.d */
#define FTANH_L      	373	/* ftanh.l */
#define FTANH_S      	374	/* ftanh.s */
#define FTANH_W      	375	/* ftanh.w */
#define FTANH_X      	376	/* ftanh.x */
#define FTENTOX_B      	377	/* ftentox.b */
#define FTENTOX_D      	378	/* ftentox.d */
#define FTENTOX_L      	379	/* ftentox.l */
#define FTENTOX_S      	380	/* ftentox.s */
#define FTENTOX_W      	381	/* ftentox.w */
#define FTENTOX_X      	382	/* ftentox.x */
#define FTEST_D      	383	/* ftest.d */
#define FTEST_S      	384	/* ftest.s */
#define FTEST_X      	385	/* ftest.x */
#define FTWOTOX_B      	386	/* ftwotox.b */
#define FTWOTOX_D      	387	/* ftwotox.d */
#define FTWOTOX_L      	388	/* ftwotox.l */
#define FTWOTOX_S      	389	/* ftwotox.s */
#define FTWOTOX_W      	390	/* ftwotox.w */
#define FTWOTOX_X      	391	/* ftwotox.x */
#define GENERIC      	392	/* generic */
#define GLOBAL      	393	/* global */
#define IDENT      	394	/* ident */
#define JMP      	395	/* jmp */
#define JSR      	396	/* jsr */
#define LCOMM      	397	/* lcomm */
#define LEA_L      	398	/* lea.l */
#define LINK_L      	399	/* link.l */
#define LINK_W      	400	/* link.w */
#define LN      	401	/* ln */
#define LONG      	402	/* long */
#define LSL_B      	403	/* lsl.b */
#define LSL_L      	404	/* lsl.l */
#define LSL_W      	405	/* lsl.w */
#define LSR_B      	406	/* lsr.b */
#define LSR_L      	407	/* lsr.l */
#define LSR_W      	408	/* lsr.w */
#define MOV_B      	409	/* mov.b */
#define MOV_L      	410	/* mov.l */
#define MOV_W      	411	/* mov.w */
#define MOVEQ_L      	412	/* moveq.l */
#define MOVM_L      	413	/* movm.l */
#define MOVM_W      	414	/* movm.w */
#define MOVP_L      	415	/* movp.l */
#define MOVP_W      	416	/* movp.w */
#define MULS_L      	417	/* muls.l */
#define MULS_W      	418	/* muls.w */
#define MULU_L      	419	/* mulu.l */
#define MULU_W      	420	/* mulu.w */
#define NBCD_B      	421	/* nbcd.b */
#define NEG_B      	422	/* neg.b */
#define NEG_L      	423	/* neg.l */
#define NEG_W      	424	/* neg.w */
#define NEGX_B      	425	/* negx.b */
#define NEGX_L      	426	/* negx.l */
#define NEGX_W      	427	/* negx.w */
#define NOP      	428	/* nop */
#define NOT_B      	429	/* not.b */
#define NOT_L      	430	/* not.l */
#define NOT_W      	431	/* not.w */
#define OR_B      	432	/* or.b */
#define OR_L      	433	/* or.l */
#define OR_W      	434	/* or.w */
#define ORG      	435	/* org */
#define PEA_L      	436	/* pea.l */
#define RESET      	437	/* reset */
#define ROL_B      	438	/* rol.b */
#define ROL_L      	439	/* rol.l */
#define ROL_W      	440	/* rol.w */
#define ROR_B      	441	/* ror.b */
#define ROR_L      	442	/* ror.l */
#define ROR_W      	443	/* ror.w */
#define ROXL_B      	444	/* roxl.b */
#define ROXL_L      	445	/* roxl.l */
#define ROXL_W      	446	/* roxl.w */
#define ROXR_B      	447	/* roxr.b */
#define ROXR_L      	448	/* roxr.l */
#define ROXR_W      	449	/* roxr.w */
#define RTE      	450	/* rte */
#define RTR      	451	/* rtr */
#define RTS      	452	/* rts */
#define SBCD_B      	453	/* sbcd.b */
#define SCC_B      	454	/* scc.b */
#define SCS_B      	455	/* scs.b */
#define SEQ_B      	456	/* seq.b */
#define SET      	457	/* set */
#define SF_B      	458	/* sf.b */
#define SGE_B      	459	/* sge.b */
#define SGT_B      	460	/* sgt.b */
#define SHI_B      	461	/* shi.b */
#define SHORT      	462	/* short */
#define SHS_B      	463	/* shs.b */
#define SLE_B      	464	/* sle.b */
#define SLO_B      	465	/* slo.b */
#define SLS_B      	466	/* sls.b */
#define SLT_B      	467	/* slt.b */
#define SMI_B      	468	/* smi.b */
#define SNE_B      	469	/* sne.b */
#define SPACE      	470	/* space */
#define SPL_B      	471	/* spl.b */
#define ST_B      	472	/* st.b */
#define STOP      	473	/* stop */
#define SUB_B      	474	/* sub.b */
#define SUB_L      	475	/* sub.l */
#define SUB_W      	476	/* sub.w */
#define SUBX_B      	477	/* subx.b */
#define SUBX_L      	478	/* subx.l */
#define SUBX_W      	479	/* subx.w */
#define SVC_B      	480	/* svc.b */
#define SVS_B      	481	/* svs.b */
#define SWAP      	482	/* swap */
#define SWAP_W      	483	/* swap.w */
#define SWBEG      	484	/* swbeg */
#define TAS_B      	485	/* tas.b */
#define TDIVS_L      	486	/* tdivs.l */
#define TDIVU_L      	487	/* tdivu.l */
#define TEXT      	488	/* text */
#define TMULS_L      	489	/* tmuls.l */
#define TMULU_L      	490	/* tmulu.l */
#define TRAP      	491	/* trap */
#define TRAPV      	492	/* trapv */
#define TST_B      	493	/* tst.b */
#define TST_L      	494	/* tst.l */
#define TST_W      	495	/* tst.w */
#define UNLK      	496	/* unlk */
#define VER_      	497	/* version */

#define OP_MAX		497	/* Max. opcode no. in the 'op' table */

/* The following two directives need opcode numbers,    */
/* but they do not lie in the normal opcode table 'op'. */

#define LABEL		498	/* Label directive opcode num. */

#define SWITCH		499	/* Switch directive opcode num. */

